OiRA

Help

1. Presentazione
2. Processo di VR
3. Identificazione + Valutazione
4. Misure di miglioramento
5. Report
6. Stato 37%

# Stato di Commercial guarding, Leicester

## Informazioni generali

Tool in uso

  Commercial guarding, Leicester

data di inizio

  5 August 2017 by angela.baumeister@company.com

Salvato

  7 June 2018 by hans.mittelmaier@company.com

## Domande e risposte tramite il modulo

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 Adempimenti e rischi non applicabili o per i quali non sono previste ulteriori misure di miglioramento
  - 3
  - 2 Adempimenti e rischi per i quali sono previste ulteriori misure di miglioramento
  - 2 Adempimenti e rischi da completare
  - 2 Non esaminato

  #### Rischi con priorità elevata

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Non esaminato

  1

  1 Adempimenti e rischi per i quali sono previste ulteriori misure di miglioramento

  1 Adempimenti e rischi da completare

  - 7 Non esaminato
  - 1
  - 1 Adempimenti e rischi per i quali sono previste ulteriori misure di miglioramento
  - 1 Adempimenti e rischi da completare

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More